==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutRenderStyleUpdatingEventArgsDescription } from "./CalloutRenderStyleUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutRenderStyleUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutRenderStyleUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a == null) {
                CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.c(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
            a.item("LabelPositionX", "Number:double");
            a.item("LabelPositionY", "Number:double");
            a.item("TargetPositionX", "Number:double");
            a.item("TargetPositionY", "Number:double");
            a.item("ActualPosition", "ExportedType:string:CalloutPlacementPositions");
            a.item("ActualPosition@names", "Top;Left;Right;Bottom;TopLeft;TopRight;BottomLeft;BottomRight");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("Background", "Brush");
            a.item("TextColor", "Brush");
            a.item("Outline", "Brush");
            a.item("LeaderBrush", "Brush");
            a.item("StrokeThickness", "Number:double");
        }
        static d(a) {
            CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.b(a);
            a.ad("CalloutRenderStyleUpdatingEventArgs", () => new CalloutRenderStyleUpdatingEventArgsDescription());
            a.ac("CalloutRenderStyleUpdatingEventArgs", CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata, 'CalloutRenderStyleUpdatingEventArgsDescriptionMetadata');
    CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutRenderStyleUpdatingEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutRenderStyleUpdatingEventArgsDescription } from "./CalloutRenderStyleUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutRenderStyleUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutRenderStyleUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a == null) {
                CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.c(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
            a.item("LabelPositionX", "Number:double");
            a.item("LabelPositionY", "Number:double");
            a.item("TargetPositionX", "Number:double");
            a.item("TargetPositionY", "Number:double");
            a.item("ActualPosition", "ExportedType:string:CalloutPlacementPositions");
            a.item("ActualPosition@names", "Top;Left;Right;Bottom;TopLeft;TopRight;BottomLeft;BottomRight");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("Background", "Brush");
            a.item("TextColor", "Brush");
            a.item("Outline", "Brush");
            a.item("LeaderBrush", "Brush");
            a.item("StrokeThickness", "Number:double");
        }
        static d(a) {
            CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.b(a);
            a.ae("CalloutRenderStyleUpdatingEventArgs", () => new CalloutRenderStyleUpdatingEventArgsDescription());
            a.ad("CalloutRenderStyleUpdatingEventArgs", CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata, 'CalloutRenderStyleUpdatingEventArgsDescriptionMetadata');
    CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutRenderStyleUpdatingEventArgsDescriptionMetadata;
})();
